#
# Author:: Daniel DeLeo (<dan@chef.io>)
# Copyright:: Copyright 2011-2016, Chef Software Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require "chef/knife"
require "chef/knife/cookbook_site_install"

class Chef::Knife::CookbookSiteVendor < Chef::Knife::CookbookSiteInstall

  def self.load_deps
    superclass.load_deps
  end

  def self.options=(new_opts)
    superclass.options = new_opts
  end

  def self.options
    superclass.options
  end

  banner(<<-B)
*************************************************
DEPRECATED: please use knife cookbook site install
*************************************************

#{superclass.banner}
B

  category "deprecated"

end
